function [net] = create_CMR(param)
% [net] = create_CMR(param);
%
% Create the CMR network given a param structure.
% 
%


net.nDim = param.nDim;

% context parameters
% temporal context
net.c_sub{1}.B = param.B_enc_temp;
net.c_sub{1}.B_enc = param.B_enc_temp;
net.c_sub{1}.B_rec = param.B_rec_temp;

% source context
net.c_sub{2}.B = param.B_enc_source;
net.c_sub{2}.B_enc = param.B_enc_source;
net.c_sub{2}.B_rec = param.B_rec_source;

% for convenience: the indices of the elements in each sub-region
net.c_sub{1}.idx = getValFromStruct(param,'c_sub1_idx',[param.nSource+1:net.nDim]);
net.c_sub{2}.idx = getValFromStruct(param,'c_sub2_idx',[1:param.nSource]);
net.f_sub{1}.idx = getValFromStruct(param,'f_sub1_idx',[param.nSource+1:net.nDim]);
net.f_sub{2}.idx = getValFromStruct(param,'f_sub2_idx',[1:param.nSource]);

net.pScale = param.pScale;
net.pDecay = param.pDecay;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% create the network structures %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% default context drift is study drift
for i = 1:length(net.c_sub)
  net.c_sub{i}.B = net.c_sub{i}.B_enc;
end

% the layers
net.f = zeros(net.nDim,1);
net.c = zeros(net.nDim,1);

% summary of lrate params
param.lrate_fc = [param.base_lrate_fc param.task_lrate_fc; 0 0];
param.lrate_cf = [param.base_lrate_cf 0; param.task_lrate_cf 0];

% the learning rate matrices
net.lrate_fc = zeros(net.nDim);
net.lrate_cf = zeros(net.nDim);

for i=1:length(net.f_sub)
  for j=1:length(net.c_sub)
    % the lrate matrices
    net.lrate_fc(net.c_sub{j}.idx,net.f_sub{i}.idx) = param.lrate_fc(i,j);
    net.lrate_cf(net.f_sub{j}.idx,net.c_sub{i}.idx) = param.lrate_cf(i,j);
  end
end

% create the connecting weight matrices
net.w_fc = eye(length(net.c),length(net.f)) * param.eye_fc;
net.w_cf = eye(length(net.f),length(net.c)) * param.eye_cf;

