function [winners,time,x] = decision_accum(param,in,noise)
% [winners,time,x] = decision_accum(param,in,noise)
%
% creates a set of leaky, competitive accumulators that determine
% which item is recalled and with what latency.
%

ncycles = size(noise,2);

K = param.K;
L = param.L;
dt = param.dt;
tau = param.tau;
eta = param.eta;
thresh = param.thresh;

% make recalled a logical
recalled = getValFromStruct(param,'recalled',false(size(in))');

dt_tau = dt/tau;
sq_dt_tau = sqrt(dt_tau);

% any inputs less than zero are set to zero
in(in<0) = 0;

x = zeros(size(in));

% lateral inhibition
lmat = ~eye(length(in),length(in)) * L;
% leak
K = ones(size(x)) * K;

%%%%%%%%%%%%%%%%%%%%%%
% VISUALIZATION TOOL % 
%%%%%%%%%%%%%%%%%%%%%%
% set this flag to 1 to observe the input vector prior to each
% recall attempt.
flag2 = 0;
if flag2 == 1
  figure(5);
  clf;
  plot(in,'.r-');
  axis([0 25 0 1]);
  keyboard
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% BEGIN ACCUMULATORS CYCLING %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

winners = [];
reset_val = thresh - thresh*0.05;

for i=1:ncycles
  % the change in each accumulator
  x = x + ((in - K.*x - lmat*x) * dt_tau + (eta*noise(:,i)*sq_dt_tau));
  x(x<0) = 0;

  % inhibition of return
  x(recalled & x>=thresh) = reset_val;
  
  % determine whether any not-yet-recalled items have crossed threshold
  if any(~recalled & x>=thresh)
    winners = find(~recalled & x>=thresh);
    break
  end
  
end % i ncycles

% calculate the amount of elapsed time
time = i * param.dt;

% determine which unit crossed; check for ties
% random tiebreak
if length(winners) > 1
  winners = randsample(winners,1);
end
