function [net,env] = init_CMR(net,env,param)
% [net,env] = init_CMR(net,env,param)
%
% Initialize a CMR network and corresponding environment
% structure. 
%
%

% do not overwrite the recording apparatus
rec = net.rec;

% reset the network state
net = create_CMR(param);
net.rec = rec;

% initialize each context sub-region to a neutral state
net.c(net.c_sub{1}.idx(1)) = 1;
net.c(net.c_sub{2}.idx(env.initTask)) = 1;

% initialize the environment. stim starts at idx 2 because first
% represents anything already in the system, such as pre-expt or prior
% list.
env.curStim = net.c_sub{1}.idx(2);
env.curSource = net.c_sub{2}.idx(env.initTask+1);
env.listIdx = [];

% if we are using pre-built semantic connections and if a list
% exists in the env structure
if env.listNum > 0
  
  % grab the indices of the to-be-presented items
  semMat = param.semMat(env.poolIdx,env.poolIdx);
  
  % check to see if there are any NaNs (words missing from the pool)
  foundnan = any(isnan(semMat(:)));
  while foundnan == 1
    % find the offending word and replace it
    nanidx = find(isnan(semMat(:,1)));
    for i=1:length(nanidx)
      env.poolIdx(nanidx(i)) = randsample(size(param.semMat,1),1);
    end
    % grab the indices of the to-be-presented items
    semMat = param.semMat(env.poolIdx,env.poolIdx);
    
    % check to see if there are any NaNs
    foundnan = any(isnan(semMat(:)));
  end
  
  % scale these by the s parameter
  semMat = semMat * param.s;
  
  % the self connections are removed
  n = length(semMat);
  diagInd = [1:n]+[0:n-1]*n;
  semMat(diagInd) = 0;
  
  % place these sem strengths in the w_cf matrix
  irange = net.f_sub{1}.idx(2:length(env.poolIdx)+1);
  net.w_cf(irange,irange) = net.w_cf(irange,irange) + semMat;
  
end

net.semMat = semMat;
