function param = param_cmr_mo70
% param = param_cmr_mo70
%
% This function creates a parameters structure for use with the CMR
% model.  Update param.semPath to reflect the local path to the
% semantic similarity file.
%
% These parameters were found using a genetic algorithm fitting
% procedure and are reported in Table 1 of the Polyn et
% al. manuscript, parameter set MO70.
%
% Note that a slight conversion is needed between the values for
% eta and tau reported here and those appearing in the manuscript.
% See README.txt, FAQ Q1.
%
% % Example:
% param = param_cmr_mo70;
%

param.B_enc_temp = 0.621;
param.B_rec_temp = 0.179;
param.B_enc_source = 0;
param.B_rec_source = 0;

param.pScale = 6.0;
param.pDecay = 0.916;

param.base_lrate_cf = 1;
param.task_lrate_cf = 0;

param.K = 0.166;
param.L = 0.284;
param.eta = 0.126;
param.tau = 310;
param.thresh = 1;
param.dt = 100;

param.s = 3.06;

param.gamma_fc = 0.559;
param.base_lrate_fc = param.gamma_fc;
param.task_lrate_fc = param.gamma_fc;
param.eye_cf = 0;
param.eye_fc = 1 - param.gamma_fc;

param.taskShiftDisrupt = 0;

param.recTime = 90000;
param.semPath = 'LSA_tfr.mat';
param.nDim = 50;
param.nSource = 3;
param.visualize_item_recall = 0;
param.mult_subj = 1;
param.justControl = 0;

param.nListsPerSubj = 20;
param.nSubj = 72;
