function [net] = record_fields(net,reclevel)
% [net] = record_fields(net,reclevel)
%
% checks the rec field and reclevel being passed in, and records
% values of the appropriate fields.
%
% if fieldname is included in the rec field, 
% and if reclevel of rec.field matches reclevel of input arg 
% then copy the net.fieldname values into rec.fieldname.data.  
%
% Example:
%     net.rec.c.reclevel = 'item';
%     net.rec.c.data = [];
%     % now this will record current state of c
%     net = record_fields(net,'item');

% loop through the rec fields
name = fieldnames(net.rec);
for fs = 1:length(name)
  % First, if this rec field corresponds to a net field
  % and if this rec field has the same reclevel as the input arg
  if isfield(net,name{fs})
    if strcmp(net.rec.(name{fs}).reclevel,reclevel)
      % if so, add val into the rec field under data
      % this will be different for scalars, vectors, and mats,
      % unless we use cells
      % RECORD SCALARS
      dataSize = size(net.(name{fs}));
      if isequal(dataSize,[1 1])
	net.rec.(name{fs}).data(end+1) = net.(name{fs});
      end
      % RECORD VECTORS
      if all([length(dataSize)==2,any(dataSize==1),any(dataSize>1)])
	net.rec.(name{fs}).data(:,end+1) = net.(name{fs});
      end
      % RECORD 2-D MATRICES
      if all([length(dataSize)==2,all(dataSize>1)])
	net.rec.(name{fs}).data(:,:,end+1) = net.(name{fs});
      end
    end % if reclevel
  end % if isfield
end % for fields

