function [data,net] = run_M62(param)
% [data,net] = run_M62(param)
%
% Simulate the Murdock (1962) experiment using the CMR model.  
%
% param - a parameters structure specifying the configuration of
% the model.
%
% Example:
%
% param = param_cmr_m62;
% [data,net] = run_M62(param);
%

nlists = param.nSubj*param.nListsPerSubj;

rand('state',sum(100*clock));

for i = 1:length(param.LL)

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % create the experimental structure %
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

  LL = param.LL(i);
  
  data.LL{i}.listLength = LL;
  data.LL{i}.recalls = zeros(nlists,LL);
  data.LL{i}.times = zeros(nlists,LL);
  data.LL{i}.nRepeat = zeros(nlists,LL);
  data.LL{i}.pres_task = zeros(nlists,LL);
  % this will be modified below
  data.LL{i}.pres_itemnos = zeros(nlists,LL);
  
  for j = 1:param.nSubj
    first = ((j-1)*param.nListsPerSubj)+1;
    data.LL{i}.subject(first:first+param.nListsPerSubj-1,1) = j;
  end
  data.LL{i}.session = ones(nlists,LL);
  data.LL{i}.listType = zeros(nlists,LL);
  data.LL{i}.react_time = zeros(nlists,LL);

  fprintf('expt structure created.\n');

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % load semantic connections if desired %
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
  load(param.semPath);
  param.semMat = LSA;
  fprintf('semantic connections loaded.\n');
  
  for j = 1:nlists
    temp = randperm(size(LSA,1));
    data.LL{i}.pres_itemnos(j,:) = temp(1:LL);
  end

  %%%%%%%%%%%%%%%%%%%%
  % run the paradigm %
  %%%%%%%%%%%%%%%%%%%%
  
  [net,temp] = simulate_CMR(param,data.LL{i});

  data.LL{i} = temp;
  
end
