function [data,net] = run_MO70(param)
% [data,net] = run_MO70(param)
%
% Simulate the Murdock and Okada (1970) experiment using the CMR model.  
%
% param - a parameters structure specifying the configuration of
% the model.
%
% Example:
%
% param = param_cmr_mo70;
% [data,net] = run_MO70(param);
% 

nlists = param.nSubj*param.nListsPerSubj;

rand('state',sum(100*clock));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% create the experimental structure %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

LL = 20;

data.listLength = LL;
data.recalls = zeros(nlists,LL);
data.times = zeros(nlists,LL);
data.nRepeat = zeros(nlists,LL);
data.pres_task = zeros(nlists,LL);
data.task = zeros(nlists,LL);
data.rec_itemnos = zeros(nlists,LL);

% this will be modified below
data.pres_itemnos = zeros(nlists,LL);

for j = 1:param.nSubj
  first = ((j-1)*param.nListsPerSubj)+1;
  data.subject(first:first+param.nListsPerSubj-1,1) = j;
end
data.session = ones(nlists,LL);
data.listType = zeros(nlists,LL);
data.react_time = zeros(nlists,LL);

fprintf('expt structure created.\n');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% load semantic connections if desired %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load(param.semPath);
param.semMat = LSA;
fprintf('semantic connections loaded.\n');

for j = 1:nlists
  temp = randperm(size(LSA,1));
  data.pres_itemnos(j,:) = temp(1:LL);
end

%%%%%%%%%%%%%%%%%%%%
% run the paradigm %
%%%%%%%%%%%%%%%%%%%%

[net,data] = simulate_CMR(param,data);


  

