function [data] = task_info(data)
% [data] = task_info(data);
%
% adds a number of useful fields to the data structure.  'pres'
% fields are ordered by serial position in the study list.  Other
% fields are ordered by position in the recall sequence.
%
% data.pres_subrec: one column for each serial position.  Logical,
% if 1, this item will be recalled on this trial (subrec ==
% 'subsequent recall')
%
% data.pres_trainno: the train that each presented item is in.
% This can be thought of as train serial position.  Trains are
% defined by task shifts, so the control lists have only one train.   
%
% data.pres_trainlen: the length of the train that each presented
% item is in.  Each train can be between 2 and 6 items in length.
%
% data.pres_sertrain: the serial position of the item within a
% particular train (e.g. the items in a train of length 3 would be
% labeled 1 2 3).
%
% data.train: for each item in the recall sequence, which train did
% it come from (pres_trainno).
%
% data.trainlen: for each item in the recall sequence, what was the
% length of the train it came from (pres_trainlen).
%
% data.sertrain: for each item in the recall sequence, what was its
% serial position in the train it came from (pres_sertrain).
%

data.pres_subrec = zeros(size(data.pres_itemnos));
data.pres_trainno = zeros(size(data.pres_task));
data.pres_trainlen = zeros(size(data.pres_task));
data.pres_sertrain = zeros(size(data.pres_task));
data.train = NaN(size(data.recalls));
data.trainlen = NaN(size(data.recalls));
data.sertrain = NaN(size(data.recalls));

for i = 1:size(data.pres_task,1)
  newtrainflag = [0 abs(diff(data.pres_task(i,:)))];
  trainno = 1;
  sertrain = 1;
  for j = 1:size(data.pres_task,2)
    
    if newtrainflag(j) == 1
      trainno = trainno + 1;
      sertrain = 1;
    end    
    data.pres_trainno(i,j) = trainno;
    data.pres_sertrain(i,j) = sertrain;
    sertrain = sertrain + 1;
  end
end

for i = 1:size(data.pres_task,1)
  data.pres_trainlen(i,:) = data.pres_sertrain(i,:);
  for j = size(data.pres_task,2)-1:-1:1
    
    if data.pres_sertrain(i,j+1) > data.pres_sertrain(i,j)

      data.pres_trainlen(i,j) = data.pres_trainlen(i,j+1);
    end
  end
end

for i=1:size(data.recalls,1)
  for j = 1:size(data.recalls,2)
    rec_idx = data.recalls(i,j);
    if rec_idx > 0
      data.pres_subrec(i,rec_idx) = 1;
      data.train(i,j) = data.pres_trainno(i,rec_idx);
      data.trainlen(i,j) = data.pres_trainlen(i,rec_idx);
      data.sertrain(i,j) = data.pres_sertrain(i,rec_idx);
    elseif rec_idx < 0
      data.train(i,j) = -999;
      data.trainlen(i,j) = -999;
      data.sertrain(i,j) = -999;
    end
  end
end





